# Roadmap

### REST API
* Specify, document and to implement (partially done: working for motors and primitives)

### Develop graphical tools
* for monitoring
* for managing the way primitives are combined
* Re-write herborist to make it more robust and remove the Qt dependency (as a web app?)

### One-click launcher
* for running v-rep and connect to it using pypot on Win/Mac/Linux

### Implement other IOs
* for gazebo
* IMU

### Primitives
* Better defined primitives and how they can be combined (using paradigm such as [Esterel](http://www.esterel-technologies.com), [Antescofo](http://repmus.ircam.fr/antescofo))

### Misc
* Working and efficient driver on mac os
